==> dotnet8_8.0.120-8.0.20.orig.tar.xz: src/arcade/Documentation/Projects/Build Analysis/LandingPage.md <==
# Build Analysis

The Build Analysis offers a set of features to make build and pull request results more actionable. 

Explore all the features offered by build analysis:

- [Build Analysis Website](https://helix.dot.net/BuildAnalysis): Find the builds that are impacted by an error, that occurs either in tests or in timelines, across the dotnet organization, in the same way as Runfo does. You can also obtain the latest report for any known issue and a list of all open issues and their impact.
- [Build Analysis GitHub Check](https://github.com/dotnet/arcade/blob/main/Documentation/Projects/Build%20Analysis/Introduction.md): Makes GitHub pull request results more actionable by highlighting build and test information most helpful to .NET developers.
- [Known Issues](https://github.com/dotnet/arcade/blob/main/Documentation/Projects/Build%20Analysis/KnownIssues.md): Report known issues so these can be automatically identified and reported on failed builds.
- [Automatic Test Retries](https://github.com/dotnet/arcade/blob/main/Documentation/Projects/Build%20Analysis/Test%20Retry%20Documentation.md): Configure tests in your repo's pull requests to automatically retry when they encounter specific errors.
- [Automatic Build Retries](https://github.com/dotnet/arcade/blob/main/Documentation/Projects/Build%20Analysis/BuildRetryOnboard.md): Configure your repo's pull request builds to automatically retry when they encounter specific errors.
- [Test Reporting Queries](https://github.com/dotnet/arcade/blob/a264eb13fea14125f3ef8d4056586cd66fa55309/Documentation/AzureDevOps/TestReportingQueries.md):  We've collected your test results data into Kusto for ease of querying and put together a few queries to get started.

<!-- Begin Generated Content: Doc Feedback -->
<sub>Was this helpful? [![Yes](https://helix.dot.net/f/ip/5?p=Documentation%5CProjects%5CBuild%20Analysis%5CLandingPage.md)](https://helix.dot.net/f/p/5?p=Documentation%5CProjects%5CBuild%20Analysis%5CLandingPage.md) [![No](https://helix.dot.net/f/in)](https://helix.dot.net/f/n/5?p=Documentation%5CProjects%5CBuild%20Analysis%5CLandingPage.md)</sub>
<!-- End Generated Content-->

==> dotnet10_10.0.100-10.0.0~rc1.orig.tar.xz: src/arcade/Documentation/Projects/Build Analysis/LandingPage.md <==
# Build Analysis

The Build Analysis offers a set of features to make build and pull request results more actionable. 

Explore all the features offered by build analysis:

- [Build Analysis Website](https://helix.dot.net/BuildAnalysis): Find the builds that are impacted by an error, that occurs either in tests or in timelines, across the dotnet organization, in the same way as Runfo does. You can also obtain the latest report for any known issue and a list of all open issues and their impact.
- [Build Analysis GitHub Check](https://github.com/dotnet/arcade/blob/main/Documentation/Projects/Build%20Analysis/Introduction.md): Makes GitHub pull request results more actionable by highlighting build and test information most helpful to .NET developers.
- [Known Issues](https://github.com/dotnet/arcade/blob/main/Documentation/Projects/Build%20Analysis/KnownIssues.md): Report known issues so these can be automatically identified and reported on failed builds.
- [Automatic Test Retries](https://github.com/dotnet/arcade/blob/main/Documentation/Projects/Build%20Analysis/Test%20Retry%20Documentation.md): Configure tests in your repo's pull requests to automatically retry when they encounter specific errors.
- [Automatic Build Retries](https://github.com/dotnet/arcade/blob/main/Documentation/Projects/Build%20Analysis/BuildRetryOnboard.md): Configure your repo's pull request builds to automatically retry when they encounter specific errors.
- [Test Reporting Queries](https://github.com/dotnet/arcade/blob/a264eb13fea14125f3ef8d4056586cd66fa55309/Documentation/AzureDevOps/TestReportingQueries.md):  We've collected your test results data into Kusto for ease of querying and put together a few queries to get started.
- [Build Analysis Pipelines Filtering](https://github.com/dotnet/arcade/blob/main/Documentation/Projects/Build%20Analysis/FilteringPipelines.md): This feature allows you to specify which pipelines are analyzed by Build Analysis for each target branch.
- [Build Analysis Pipelines Filtering](https://github.com/dotnet/arcade/blob/main/Documentation/Projects/Build%20Analysis/EscapeMechanismforBuildAnalysis.md): This feature allows users to override the build analysis conclusion and set it to a successful conclusion

<!-- Begin Generated Content: Doc Feedback -->
<sub>Was this helpful? [![Yes](https://helix.dot.net/f/ip/5?p=Documentation%5CProjects%5CBuild%20Analysis%5CLandingPage.md)](https://helix.dot.net/f/p/5?p=Documentation%5CProjects%5CBuild%20Analysis%5CLandingPage.md) [![No](https://helix.dot.net/f/in)](https://helix.dot.net/f/n/5?p=Documentation%5CProjects%5CBuild%20Analysis%5CLandingPage.md)</sub>
<!-- End Generated Content-->
